@@ -1,10 +1,10 @@
 '''
 Author: BDFD
 Date: 2022-03-01 17:28:34
-LastEditTime: 2022-06-24 13:11:58
+LastEditTime: 2022-04-24 08:09:55
 LastEditors: BDFD
 Description: 
-FilePath: \Section5.2-PyPi-WES_Calculation\WES_Calculation\greenampt.py
+FilePath: \5.2-PyPi-WES_Calculation\WES_Calculation\greenampt.py
 '''
 
 import matplotlib.pyplot as plt
@@ -344,14 +344,14 @@ def greenampt(thetai, thetas, Psi, K, dti, nin, dd, i, iyesno, ss1, ss2, ss3):
     
     plt.xlim(0,dti*len(i))
     ax1.legend()
-    plt.rcParams['font.sans-serif'] = ['FangSong']
     plt.rcParams["font.family"]="sans-serif"
-    #plt.rcParams['axes.unicode_minus'] = False
+    plt.rcParams['font.sans-serif'] = ['SimHei']
+    plt.rcParams['axes.unicode_minus'] = False
+    plt.savefig('greenampt.png')
+    # plt.show()
     #mpl.rcParams['axes.unicode_minus'] = False
     #matplotlib.rc('font', family='FangSong')
-    #mpl.rcParams['font.sans-serif'] = ['Microsoft YaHei']
-    plt.savefig('./static/greenampt.jpg')
-    # plt.show()
+    #mpl.rcParams['font.sans-serif'] = ['Microsoft YaHei'] 
     img = io.BytesIO()
     plt.savefig(img, format='png')
     img.seek(0)
