@@ -1,7 +1,7 @@
 '''
 Author: BDFD
 Date: 2022-02-24 15:23:11
-LastEditTime: 2022-06-24 12:48:23
+LastEditTime: 2022-06-14 14:37:48
 LastEditors: BDFD
 Description: 
 FilePath: \Section5.2-PyPi-WES_Calculation\WES_Calculation\gumbel.py
@@ -329,10 +329,11 @@ def gumbel(pq, unitt, unitx, i1, i2, i3, meanx, sdx, n, dataolist):
         for i in range(1,len(Tt)+1):
             data3 += ((str(Tt[i-1]),str(round(xTt1[i-1],2)),str(round(xTt2[i-1],2))),)
         
-        note_4_1 = '2) 分布参数'
+        note_4_1 = '2) 分布参数 (单位：'+str(unitx)+')'
+        #note_4_1 = '2) 分布参数'
         note4.append(note_4_1)
-        data4 += (('位置系数',str(round(mode1,3)),str(round(mode2,3))),)
-        data4 += (('尺度系数',str(round(scale1,3)),str(round(scale2,3))),)
+        data4 += (('位置系数 \u03B1',str(round(mode1,3)),str(round(mode2,3))),)
+        data4 += (('尺度系数 \u03B2',str(round(scale1,3)),str(round(scale2,3))),)
         # print(' ') 
 
         if i2==2:  
@@ -389,10 +390,14 @@ def gumbel(pq, unitt, unitx, i1, i2, i3, meanx, sdx, n, dataolist):
         secax.xaxis.set_major_formatter(PTmatl)
         secax.tick_params(direction="in")
 
-        plt.legend()
-        plt.rcParams['font.sans-serif'] = ['KaiTi']#FangSong
-        plt.savefig('./static/gumbel.jpg')
+        #plt.legend()
+        plt.legend(fontsize=9,facecolor='white',framealpha=1)
+        # plt.rcParams['font.sans-serif'] = ['KaiTi']#FangSong
         # plt.show()
+        plt.rcParams["font.family"]="sans-serif"
+        plt.rcParams['font.sans-serif'] = ['SimHei']
+        plt.rcParams['axes.unicode_minus'] = False
+        plt.savefig('gumbel.png')
         img = io.BytesIO()
         plt.savefig(img, format='png')
         img.seek(0)
