@@ -1,10 +1,10 @@
 '''
 Author: BDFD
 Date: 2022-04-20 13:16:40
-LastEditTime: 2022-06-24 13:12:33
+LastEditTime: 2022-05-04 14:07:19
 LastEditors: BDFD
 Description: 
-FilePath: \Section5.2-PyPi-WES_Calculation\WES_Calculation\wavespectra.py
+FilePath: \5.2-PyPi-WES_Calculation\WES_Calculation\wave.py
 '''
 import matplotlib.pyplot as plt
 from matplotlib.ticker import FixedLocator, FixedFormatter
@@ -625,7 +625,7 @@ def wave(c1, d, X, U, el, gamma, Hs, Tz, Ts, Tp):
     note.extend([''])
     # content.extend(['说明：'])
     # content.extend(['1. 计算结果中的频率均为循环频率f(Hz)。'])
-    content.extend(['计算结果中的频率均为循环频率f(Hz)。'])
+    content.extend(['计算结果中的频率均为循环频率f (Hz)。'])
     # note.extend(['2. 表中各物理量： Smax为谱密度峰值，fp为Smax的循环频率（除非另有说明），Tp=1/fp，m\u2080为谱零阶原点矩，m\u2081为谱1阶原点矩，m\u2082为谱二阶原点矩，m\u2084为谱四阶原点矩，\u03BD为谱宽[=(m\u2080m\u2082/m\u2081\u00b2-1)\u2070\u22C5\u2075]，\u03B5为谱带宽[=(1-m\u2082\u00b2/m\u2080/m\u2084)\u2070\u22C5\u2075]，fa为平均频率(=m\u2081/m\u2080)，Ta=1/fa，\
     # frms为均方根频率[=(m\u2082/m\u2080)\u2070\u22C5\u2075]，Tm\u2080\u2082=1/frms，Hsm\u2080为通过m\u2080按m\u2080和Hs间近似关系估计得到的Hs。'])
     # content.extend(['2. 表中各物理量： m\u208b\u2081为谱负一阶原点矩，m\u2080为谱零阶原点矩，m\u2081为谱1阶原点矩，m\u2082为谱二阶原点矩，m\u2084为谱四阶原点矩，\u03BD为谱宽[=(m\u2080m\u2082/m\u2081\u00b2-1)\u2070\u22C5\u2075]，\u03B5为谱带宽[=(1-m\u2082\u00b2/m\u2080/m\u2084)\u2070\u22C5\u2075]，Hsm\u2080为通过m\u2080按m\u2080和Hs间近似关系估计得到的Hs，\
@@ -681,14 +681,14 @@ def wave(c1, d, X, U, el, gamma, Hs, Tz, Ts, Tp):
                 content.extend(['在结果表中，P-M谱的负一至二阶原点矩按理论方法求得，其它所有原点矩均为数值近似值。在为P-M估计\u03B5时，m\u2080和m\u2082也采用数值解，但这两个数值解未在表中列出。'])      
         if Hs!=None:#20220327               
             # str1="6. 计算结果中的O-H谱仅为最可能谱型。表中的fp为其低频成分的峰值频率，Smax位于fp处，高频成分的峰值频率在"+str(round(fp2OH, 2))+"Hz。"    
-            str1="计算结果中的O-H谱仅为最可能谱型。表中的fp为其低频成分的峰值频率，Smax位于fp处，高频成分的峰值频率在"+str(round(fp2OH, 2))+"Hz。"    
+            str1="计算结果中的O-H谱仅为最可能谱型。表中的fp为其低频成分的峰值频率，Smax位于fp处，高频成分的峰值频率在"+str(round(fp2OH, 2))+" Hz。"    
             content.append(str1)
         else:
             # content.extend(['6. 由于输入参数不满足O-H谱的要求，该谱在此不适用。'])
             content.extend(['由于输入参数不满足O-H谱的要求，该谱在此不适用。'])
         if Hs!=None and Tp!=None and X!=None: #20220327 
             # str2='7. 对于Torsethaugen-S谱，Smax直接从图中读取，Tp为输入的参数，fp为Tp的倒数。fp实为主峰频率，次峰频率在'+str(round(1 / Tps * (Tp <= Tf) + 1 / Tpw * (Tp > Tf), 2))+ 'Hz。'  # 20220328
-            str2='对于sT谱，Smax直接从图中读取，Tp为输入的参数，fp为Tp的倒数。fp实为主峰频率，次峰频率在'+str(round(1 / Tps * (Tp <= Tf) + 1 / Tpw * (Tp > Tf), 2))+ 'Hz。'  # 20220328
+            str2='对于sT谱，Smax直接从图中读取，Tp为输入的参数，fp为Tp的倒数。fp实为主峰频率，次峰频率在'+str(round(1 / Tps * (Tp <= Tf) + 1 / Tpw * (Tp > Tf), 2))+ ' Hz。'  # 20220328
             content.append(str2)           
         else:
             # content.extend(['7. 由于输入参数不满足Torsethaugen-S谱的要求，该谱在此不适用。'])
@@ -706,8 +706,11 @@ def wave(c1, d, X, U, el, gamma, Hs, Tz, Ts, Tp):
     plt.ylabel('S (m$^2$s)')         
     plt.legend()
     # plt.rcParams['font.sans-serif'] = ['Kaiti']  # ['FangSong']
-    plt.savefig('./static/wavespectra.jpg')
     # plt.show()
+    plt.rcParams["font.family"]="sans-serif"
+    plt.rcParams['font.sans-serif'] = ['SimHei']
+    plt.rcParams['axes.unicode_minus'] = False
+    plt.savefig('wavespectra.png')
     img = io.BytesIO()
     plt.savefig(img, format='png')
     img.seek(0)
